M3ELinearWavyProgressIndicator class
A Material 3 Expressive linear wavy progress indicator.
Progress indicators express an unspecified wait time or display the duration of a process. This expressive wavy variant displays the progress as a waveform.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- M3ELinearWavyProgressIndicator
Constructors
-
M3ELinearWavyProgressIndicator({Key? key, double? value, Color? color, Animation<
Color?> ? valueColor, Color? backgroundColor, double strokeWidth = M3EProgressIndicatorDefaults.linearStrokeWidth, double trackStrokeWidth = M3EProgressIndicatorDefaults.linearTrackStrokeWidth, double gapSize = M3EProgressIndicatorDefaults.linearIndicatorTrackGapSize, double stopSize = M3EProgressIndicatorDefaults.linearTrackStopIndicatorSize, double wavelength = M3EProgressIndicatorDefaults.linearDeterminateWavelength, double waveSpeed = M3EProgressIndicatorDefaults.linearWaveSpeed, double height = M3EProgressIndicatorDefaults.linearContainerHeight, double width = double.infinity, double amplitude(double)?}) -
const
Properties
- amplitude → double Function(double)?
-
Function that returns amplitude (between 0.0 and 1.0) based on progress.
final
- backgroundColor → Color?
-
The background color of the track.
final
- color → Color?
-
The color of the active progress indicator.
final
- gapSize → double
-
The gap size between the active progress and the track.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
Height of the container, accommodating the wave amplitude.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopSize → double
-
The size of the stop indicator at the end of the track.
final
- strokeWidth → double
-
The stroke width of the active wavy line.
final
- trackStrokeWidth → double
-
The stroke width of the track.
final
- value → double?
-
The progress value, between 0.0 and 1.0.
If null, the indicator is indeterminate.
final
-
valueColor
→ Animation<
Color?> ? -
The animation of the active progress indicator color.
final
- wavelength → double
-
The preferred wavelength of the wave.
final
- waveSpeed → double
-
The speed of the wave scrolling (logical pixels per second).
final
- width → double
-
Width of the progress bar.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< M3ELinearWavyProgressIndicator> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited